@@ -1,15 +1,10 @@
 import time
 import asyncio
 
-import requests
 import aiohttp
+import requests
 
-from python3_anticaptcha import (
-    create_task_url,
-    app_key,
-    get_async_result,
-    get_sync_result,
-)
+from python3_anticaptcha import app_key, create_task_url, get_sync_result, get_async_result
 
 
 class CustomCaptchaTask:
@@ -30,9 +25,7 @@ class CustomCaptchaTask:
         :param callbackUrl: URL для решения капчи с ответом через callback
 		"""
         if sleep_time < 5:
-            raise ValueError(
-                f"Param `sleep_time` must be greater than 5. U set - {sleep_time}"
-            )
+            raise ValueError(f"Param `sleep_time` must be greater than 5. U set - {sleep_time}")
         self.sleep_time = sleep_time
 
         # Пайлоад для создания задачи
@@ -73,7 +66,7 @@ class CustomCaptchaTask:
         self.task_payload["task"].update({"imageUrl": imageUrl})
         # Отправляем на антикапча параметры фанкапич,
         # в результате получаем JSON ответ содержащий номер решаемой капчи
-        captcha_id = requests.post(create_task_url, json=self.task_payload).json()
+        captcha_id = requests.post(create_task_url, json=self.task_payload, verify=False).json()
 
         # Проверка статуса создания задачи, если создано без ошибок - извлекаем ID задачи, иначе возвращаем ответ сервера
         if captcha_id["errorId"] == 0:
@@ -89,9 +82,7 @@ class CustomCaptchaTask:
         else:
             # Ждем решения капчи
             time.sleep(self.sleep_time)
-            return get_sync_result(
-                result_payload=self.result_payload, sleep_time=self.sleep_time
-            )
+            return get_sync_result(result_payload=self.result_payload, sleep_time=self.sleep_time)
 
 
 class aioCustomCaptchaTask:
@@ -112,9 +103,7 @@ class aioCustomCaptchaTask:
         :param callbackUrl: URL для решения капчи с ответом через callback
 		"""
         if sleep_time < 5:
-            raise ValueError(
-                f"Param `sleep_time` must be greater than 5. U set - {sleep_time}"
-            )
+            raise ValueError(f"Param `sleep_time` must be greater than 5. U set - {sleep_time}")
         self.sleep_time = sleep_time
 
         # Пайлоад для создания задачи
